summaryrefslogtreecommitdiffstats
path: root/khtml/kmultipart
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/kmultipart')
-rw-r--r--khtml/kmultipart/Makefile.am2
-rw-r--r--khtml/kmultipart/README4
-rw-r--r--khtml/kmultipart/kmultipart.cpp16
-rw-r--r--khtml/kmultipart/kmultipart.desktop2
-rw-r--r--khtml/kmultipart/kmultipart.h2
5 files changed, 13 insertions, 13 deletions
diff --git a/khtml/kmultipart/Makefile.am b/khtml/kmultipart/Makefile.am
index b6d6af0df..e16d7f683 100644
--- a/khtml/kmultipart/Makefile.am
+++ b/khtml/kmultipart/Makefile.am
@@ -9,7 +9,7 @@ libkmultipart_la_LIBADD = $(LIB_KPARTS) $(top_builddir)/kio/httpfilter/libhttpfi
libkmultipart_la_DEPENDENCIES = $(LIB_KPARTS)
libkmultipart_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN)
-# Automatically generate moc files
+# Automatically generate tqmoc files
METASOURCES = AUTO
# Install the .desktop file into the kde_services directory
diff --git a/khtml/kmultipart/README b/khtml/kmultipart/README
index c8a342d68..14c871b7b 100644
--- a/khtml/kmultipart/README
+++ b/khtml/kmultipart/README
@@ -1,5 +1,5 @@
KMultiPart implements "server push" for KHTML/Konqueror:
-it handles the multipart/mixed and multipart/x-mixed-replace
+it handles the multipart/mixed and multipart/x-mixed-tqreplace
mimetype, embedding the appropriate component (part).
Documentation at http://www.netscape.com/assist/net_sites/pushpull.html
@@ -12,5 +12,5 @@ Testcases:
TODO:
* Use the new streaming API of KParts to pipe data into the part,
the current code does that for KHTML only.
-* Change KHTML so that it embeds KMultiPart for images which send multipart/x-mixed-replace
+* Change KHTML so that it embeds KMultiPart for images which send multipart/x-mixed-tqreplace
data.
diff --git a/khtml/kmultipart/kmultipart.desktop b/khtml/kmultipart/kmultipart.desktop
index 6419edac6..3bec7ad0f 100644
--- a/khtml/kmultipart/kmultipart.desktop
+++ b/khtml/kmultipart/kmultipart.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=Service
-MimeType=multipart/mixed;multipart/x-mixed-replace
+MimeType=multipart/mixed;multipart/x-mixed-tqreplace
Name=Embeddable Component for multipart/mixed
Name[af]=Inlegbare Komponent vir multideel/gemeng
Name[be]=Унутраны кампанент для multipart/mixed
diff --git a/khtml/kmultipart/kmultipart.h b/khtml/kmultipart/kmultipart.h
index f3bf95219..a17269d74 100644
--- a/khtml/kmultipart/kmultipart.h
+++ b/khtml/kmultipart/kmultipart.h
@@ -40,7 +40,7 @@ class KMultiPart : public KParts::ReadOnlyPart
{
Q_OBJECT
public:
- KMultiPart( TQWidget *parentWidget, const char *widgetName,
+ KMultiPart( TQWidget *tqparentWidget, const char *widgetName,
TQObject *parent, const char *name, const TQStringList& );
virtual ~KMultiPart();
diff --git a/khtml/kmultipart/kmultipart.cpp b/khtml/kmultipart/kmultipart.cpp
index 17ea9d485..a9fef06b5 100644
--- a/khtml/kmultipart/kmultipart.cpp
+++ b/khtml/kmultipart/kmultipart.cpp
@@ -93,7 +93,7 @@ Data for the second and last object.
*/
-KMultiPart::KMultiPart( TQWidget *parentWidget, const char *widgetName,
+KMultiPart::KMultiPart( TQWidget *tqparentWidget, const char *widgetName,
TQObject *parent, const char *name, const TQStringList& )
: KParts::ReadOnlyPart( parent, name )
{
@@ -101,7 +101,7 @@ KMultiPart::KMultiPart( TQWidget *parentWidget, const char *widgetName,
setInstance( KMultiPartFactory::instance() );
- TQVBox *box = new TQVBox( parentWidget, widgetName );
+ TQVBox *box = new TQVBox( tqparentWidget, widgetName );
setWidget( box );
m_extension = new KParts::BrowserExtension( this );
@@ -234,7 +234,7 @@ void KMultiPart::slotData( KIO::Job *job, const TQByteArray &data )
}
else if ( !qstrnicmp( line.data(), "Content-Encoding:", 17 ) )
{
- TQString encoding = TQString::fromLatin1(line.data()+17).stripWhiteSpace().lower();
+ TQString encoding = TQString::tqfromLatin1(line.data()+17).stripWhiteSpace().lower();
if (encoding == "gzip" || encoding == "x-gzip") {
m_gzip = true;
} else {
@@ -245,8 +245,8 @@ void KMultiPart::slotData( KIO::Job *job, const TQByteArray &data )
else if ( !qstrnicmp( line.data(), "Content-Type:", 13 ) )
{
Q_ASSERT( m_nextMimeType.isNull() );
- m_nextMimeType = TQString::fromLatin1( line.data() + 14 ).stripWhiteSpace();
- int semicolon = m_nextMimeType.find( ';' );
+ m_nextMimeType = TQString::tqfromLatin1( line.data() + 14 ).stripWhiteSpace();
+ int semicolon = m_nextMimeType.tqfind( ';' );
if ( semicolon != -1 )
m_nextMimeType = m_nextMimeType.left( semicolon );
kdDebug() << "m_nextMimeType=" << m_nextMimeType << endl;
@@ -266,14 +266,14 @@ void KMultiPart::slotData( KIO::Job *job, const TQByteArray &data )
else if ( !line.isEmpty() ) // this happens with e.g. Set-Cookie:
kdDebug() << "Ignoring header " << line << endl;
} else {
- if ( !qstrncmp( line, m_boundary, m_boundaryLength ) )
+ if ( !tqstrncmp( line, m_boundary, m_boundaryLength ) )
{
#ifdef DEBUG_PARSING
kdDebug() << "boundary found!" << endl;
kdDebug() << "after it is " << line.data() + m_boundaryLength << endl;
#endif
// Was it the very last boundary ?
- if ( !qstrncmp( line.data() + m_boundaryLength, "--", 2 ) )
+ if ( !tqstrncmp( line.data() + m_boundaryLength, "--", 2 ) )
{
#ifdef DEBUG_PARSING
kdDebug() << "Completed!" << endl;
@@ -312,7 +312,7 @@ void KMultiPart::setPart( const TQString& mimeType )
guiFactory->removeClient( this );
kdDebug() << "KMultiPart::setPart " << mimeType << endl;
delete m_part;
// Try to find an appropriate viewer component
m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>
( m_mimeType, TQString::null, widget(), 0L, this, 0L );
if ( !m_part ) {
@@ -312,7 +312,7 @@ void KMultiPart::setPart( const TQString& mimeType )
kdDebug() << "KMultiPart::setPart " << mimeType << endl;
delete m_part;
- // Try to find an appropriate viewer component
+ // Try to tqfind an appropriate viewer component
m_part = KParts::ComponentFactory::createPartInstanceFromQuery<KParts::ReadOnlyPart>
( m_mimeType, TQString::null, widget(), 0L, this, 0L );